@@ -46,7 +46,25 @@ QString HolidayParserDriver::fileDescription() const
     return m_fileDescription;
 }
 
-Holiday::List HolidayParserDriver::parseHolidays(const QDate &startDate, const QDate &endDate)
+Holiday::List HolidayParserDriver::parseHolidays(const QDate &startDate, const QDate &endDate, const QString &category)
+{
+    parseHolidays(startDate, endDate);
+    Holiday::List m_resultListTemp = m_resultList;
+    m_resultList.clear();
+
+    for (const KHolidays::Holiday &holidayCat : m_resultListTemp) {
+        for (const QString &mCategoryList : holidayCat.categoryList()) {
+            if (mCategoryList == category) {
+                m_resultList.append(holidayCat);
+                break;
+            }
+        }
+    }
+
+    return m_resultList;
+}
+
+Holiday::List HolidayParserDriver::parseRawHolidays(const QDate &startDate, const QDate &endDate)
 {
     m_resultList.clear();
     if (startDate.isNull() || endDate.isNull()) {
@@ -55,8 +73,14 @@ Holiday::List HolidayParserDriver::parseHolidays(const QDate &startDate, const Q
     m_requestStart = startDate;
     m_requestEnd = endDate;
     parse();
+    return m_resultList;
+}
 
-    for (int year = startDate.year(); year < endDate.year(); ++year) {
+Holiday::List HolidayParserDriver::parseHolidays(const QDate &startDate, const QDate &endDate)
+{
+    parseRawHolidays(startDate, endDate);
+
+    for (int year = startDate.year(); year <= endDate.year(); ++year) {
         for (auto s : {AstroSeasons::JuneSolstice, AstroSeasons::DecemberSolstice, AstroSeasons::MarchEquinox, AstroSeasons::SeptemberEquinox}) {
             const auto dt = AstroSeasons::seasonDate(s, year);
             if (dt >= startDate && dt <= endDate) {
